struct FuncType {
obj_id: TypeId,
method_id: TypeId,
}Expand description
Actual types to use when looking up a function in our HashMap.
Fields
obj_id: TypeIdThe type of object to which this function applies.
method_id: TypeIdThe type of method to which this function applies.