struct Caster {
cast_to_ref: Box<dyn Any + Send + Sync>,
cast_to_arc: Box<dyn Any + Send + Sync>,
}Expand description
A single entry in a CastTable.
Each Caster exists for one concrete object type “O”, and one trait type “Tr”.
Note that we use Box here in order to support generic types: you can’t
get a &'static reference to a function that takes a generic type in
current rust.
Fields
cast_to_ref: Box<dyn Any + Send + Sync>Actual type: fn(Arc<dyn Object>) -> Arc<dyn Tr>
Panics if Object does not have the expected type (O).
cast_to_arc: Box<dyn Any + Send + Sync>Actual type: fn(Arc<dyn Object>) -> Arc<dyn Tr>
Panics if Object does not have the expected type (O).